@@ -12,7 +12,7 @@ use Compress::Zlib();
 use JSON();
 use overload '""' => 'string';
 
-our $VERSION = 0.13;
+our $VERSION = 0.14;
 
 sub new {
     my ( $class, $params ) = @_;
@@ -59,6 +59,9 @@ sub hashref {
 
 sub string {
     my ( $self, $string ) = @_;
+    if ( defined $string ) {
+        $string =~ s/^(\x{ef}\x{bb}\x{bf})//smxg;
+    }
     my $json = JSON->new();
     $json = $json->utf8();
     $json = $json->allow_blessed(1);
@@ -468,7 +471,7 @@ Archive::Har - Provides an interface to HTTP Archive (HAR) files
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =for stopwords xml gzip stringified HAR gzipped gzipping JSON hashref
 
